@@ -46,11 +46,14 @@ class BlingController:
 
         url = f"{self.base_url}/{produto.sku}/json?estoque=S"
         response = await self.request.request(method="POST", url=url, data=data)
-        print(f"Bling {response.status:>10}", end="")
+        print(f"Bling {response.status:>4}", end=" ")
 
-        if response.status == 201:
+        if response.status == 200:
             logger.info(f"O produto '{produto.sku}' foi atualizado.")
             return True
+        
+        elif response.status == 429:
+            response = await self.request.request(method="POST", url=url, data=data)
 
         else:
             logger.warning(f"O produto '{produto.sku}' não pode ser atualizado.")
